.. Skan documentation master file, created by
   sphinx-quickstart on Tue Dec 12 15:07:05 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Skeleton analysis with Skan 🦴📏
================================

Skan is a pure Python library to analyse skeleton images.

.. toctree::
   :maxdepth: 3

   getting_started/index
   examples/index
   api/api
   Miscellaneous <misc/index>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
